/*
 * File:		nbuf.h
 * Purpose:		Definitions for Network Buffer Allocation.
 *
 * Notes:		These routines implement a static buffer scheme.
 *
 * Author:		Eric DeVolder
 * Date:		11-8-95
 *
 * Modifications:
 *
 */

#ifndef _NBUF_H
#define _NBUF_H

#include "basictypes.h" 

/*
 * Type definition of a network buffer.  The value 1500 is chosen
 * because that is what the Ethernet maximum is.
 */
typedef struct
{
	UINT8			data[1500];		/* actual data		*/
	int			length;			/* actual length	*/
	int			used;			/* buffer in use or not */
} NBUF;

/*
 * Functions to manipulate the network buffers.
 */
void nbuf_init (void);

NBUF * nbuf_allocate (void);

void nbuf_release (NBUF *);

NBUF * nbuf_init_traversal (int);

NBUF * nbuf_traverse (NBUF *, int);

#endif 	/* _NBUF_H */
