#include <string.h>

#include "nif.h"

int nif_proto( NIF *nif, UINT16 proto )
{
  int index;
  
  /* see if the protocol is registered */
  for (index = 0; index < nif->num_proto; index++ )
    if (nif->proto[index].protocol == proto)
      return TRUE;

  /* nope - bomb out */
  return FALSE;
}

int nif_proto_handler( NIF *nif, UINT16 proto, UINT8 *data, int length )
{
  int index;
  int keep;

  /* search for the protocol and run it's handler */
  keep = FALSE;
  for ( index = 0; index < nif->num_proto; index++ )
    if (nif->proto[index].protocol == proto)
      keep = nif->proto[index].handler( nif, data, length );

  /* return whether we need to keep the packet further */
  return keep;
}


void *nif_proto_config( NIF *nif, UINT16 proto )
{
  int index;

  /* search for protocol and return config pointer */
  for ( index = 0; index < nif->num_proto; index++ )
    if (nif->proto[index].protocol == proto)
      return nif->proto[index].config;

  return NULL;
}

int nif_bind_proto( NIF *nif, UINT16 proto, void *handler, void *info )
{
  /* if max capacity bomb out */
  if ( nif->num_proto >= MAX_SUP_PROTO )
    return FALSE;

  /* register the protocol with the interface */
  nif->proto[nif->num_proto].protocol = proto;
  nif->proto[nif->num_proto].handler  = handler;
  nif->proto[nif->num_proto].config   = info;

  /* bump the no of protocols */
  nif->num_proto = nif->num_proto + 1;
  
  return TRUE;
}


NIF *nif_create( NIF *nif, const char *name )
{
  int index;

  strncpy( nif->name, name, 16 );

  for ( index = 0; index < 6; index++ )
  {
    nif->hwa[index] = 0;
    nif->broadcast[index] = -1;
  }

  nif->hwa_size = 6;

  for ( index = 0; index < MAX_SUP_PROTO; index++ )
  {
    nif->proto[index].protocol = 0;
    nif->proto[index].handler  = NULL;
    nif->proto[index].config   = 0;
  }

  nif->reset   = NULL;
  nif->start   = NULL;
  nif->stop    = NULL;
  nif->send    = NULL;
  nif->receive = NULL;

  nif->nic    = NULL;
  nif->vector = 0;

  nif->next_receive = 0;
  
  nif->f_rx     = 0;
  nif->f_tx     = 0;
  nif->f_rx_err = 0;
  nif->f_tx_err = 0;
  nif->f_err    = 0;

  return nif;
}
