/*
 * File:		nif.h
 * Purpose:		Definition of a Network InterFace.
 *
 * Notes:
 *
 * Author:		Eric DeVolder
 * Date:		11-8-95
 *
 * Modifications:
 *
 */

#ifndef _NIF_H
#define _NIF_H

#include "eth.h"

typedef struct
{
	UINT16	protocol;
	int	(*handler)( 	void *	/* nif */,
				UINT8 *	/* proto header */,
				int	/* length */);
	void	*config;	/* pointer to protocol defined config info */
} SUP_PROTO;

typedef
UINT8	HWA_ADDR_P[];

typedef struct NIF_t
{
	char		name[16];
	ETH_ADDR	hwa;	/* ethernet card hardware address */
	ETH_ADDR	broadcast;	/* ethernet broadcast address */
	int			hwa_size;
	int			mtu;	/* hardware maximum transmission unit */

	SUP_PROTO	proto[MAX_SUP_PROTO];
	unsigned short	num_proto;

	int		(*reset)(struct NIF_t *);
	void	(*start)(struct NIF_t *);
	void	(*stop)(struct NIF_t *);
	int		(*send)(struct NIF_t *,
					HWA_ADDR_P, HWA_ADDR_P, UINT16, int, UINT8 *);
	void	(*receive)(struct NIF_t *);

	void	*nic;	/* base address of NIC chipset */
	int		vector;	/* vector used by device */
	unsigned int	next_receive;	/* needed by the SEEQ */

	unsigned int	f_rx;
	unsigned int	f_tx;
	unsigned int	f_rx_err;
	unsigned int	f_tx_err;
	unsigned int	f_err;
} NIF;


/*************************************************************/
NIF *
nif_create ( NIF *, const char *);

void
nif_init (void);

#if 0
void *
nif_proto_handler (NIF *, UINT16);
#else
int
nif_proto (NIF *, UINT16);

int
nif_proto_handler (NIF *, UINT16, UINT8 *, int);
#endif

void *
nif_proto_config (NIF *, UINT16);

int
nif_bind_proto (NIF *, UINT16, void *, void *);

#endif
